# Copyright (c) 2012,2013 MailStore Software GmbH
# 
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
# 
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

"""
in some cases after an upgrade of mailstore to v7 or newer
some folders might be created under a new name
the Inbox e.g. might be renamed to INBOX
in that cases old mails are in Inbox, new ones are in INBOX

it is not a good idea to rename INBOX to Inbox, because mailstore will recreate the
INBOX folder every time it finds new mails in it in the source (mailbox)

so the preferred way is, to rename Inbox to INBOX

this script scans for ALL folders that end [!!!] with "Inbox" and renames them to "[..]INBOX"
if there is a folder structure like Inbox\Project1\Inbox only the root-"Inbox" will be renamed
the resulting name would be INBOX\Project1\Inbox, if you want to rename the deeper level,
you have to re-run the script

Create a backup before you execute this script.
"""

# MailStore Management API connection settings
HOST = "localhost"
USER = "admin"
PASS = "admin"
PORT = 8463

################### DON'T CHANGE ANYTHING BELOW THIS LINE ###################
import mailstoreapi
from time import sleep

#this function renames the foldername that is passed from process_folders
def rename_inbox(foldername):
    global api
    if foldername.endswith("Inbox"):
        targetfolder = foldername.replace("Inbox","INBOX")
        print("+---------------------------------")
        print("|renaming folder {} -> {}".format(foldername,targetfolder))
        token = api.MoveFolder(foldername,targetfolder, False)
        status = api.GetToken(token)
        while status["progressPercentage"] < 100:      
            print("|percent done:",status["progressPercentage"])
            sleep(1)
            status = api.GetToken(token)
        else:
            print("|percent done:",status["progressPercentage"])
            print("|"+status["status"])
            for v in status["messages"]:
                print("|"+v["text"])             
        print("+---------------------------------")          
    else:
        print(foldername)
    
#this functions recurses into all subfolders
def process_folders(folders,external_function=print,deepness=0, showpath=1, path=""):
    for folder in folders:
        FolderPrintName = folder["name"] if not showpath else path+folder["name"]
        output =" "*deepness*4+FolderPrintName
        external_function(output)
        if folder["hasChildFolders"]:
           process_folders(folder["childFolders"], external_function, deepness+1 if not showpath else deepness,showpath,path=FolderPrintName+"/")

 
api = mailstoreapi.ManagementAPI(USER,PASS,HOST,PORT)

folders = api.GetChildFolders()["childFolders"]
process_folders(folders,rename_inbox)
print(("*"*25+"\n")*2)
folders = api.GetChildFolders()["childFolders"]
process_folders(folders)


